@@ -62,4 +62,14 @@ ALTER TABLE Plans ADD COLUMN IF NOT EXISTS ptv_max_dose real;
 ALTER TABLE Plans ADD COLUMN IF NOT EXISTS ptv_min_dose real;
 -- The following columns have been added as of DVH Analytics 0.9.2
 ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS centroid_dist_to_iso_min real;
-ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS centroid_dist_to_iso_max real;
\ No newline at end of file
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS centroid_dist_to_iso_max real;
+-- The following columns have been added as of DVH Analytics 0.9.4
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS ovh_string text;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS ovh_min real;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS ovh_mean real;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS ovh_median real;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS ovh_max real;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS ovh_25 real;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS ovh_75 real;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS dist_to_ptv_25 real;
+ALTER TABLE DVHs ADD COLUMN IF NOT EXISTS dist_to_ptv_75 real;
