@@ -25,6 +25,8 @@ from dvha.tools.utilities import (
     set_msw_background_color,
     set_frame_icon,
     backup_sqlite_db,
+    is_edge_backend_available,
+    is_windows,
 )
 from dvha.db import sql_columns
 from dvha.db.sql_connector import DVH_SQL
@@ -877,6 +879,9 @@ class UserSettings(wx.Frame):
         self.dvh_bin_width_input = wx.TextCtrl(
             self, wx.ID_ANY, str(self.options.dvh_bin_width)
         )
+        self.ovh_resolution_input = wx.TextCtrl(
+            self, wx.ID_ANY, str(self.options.OVH_RESOLUTION)
+        )
         self.dvh_bin_max_dose = wx.TextCtrl(self, wx.ID_ANY, "")
         self.dvh_bin_max_dose_units = wx.ComboBox(
             self,
@@ -945,8 +950,22 @@ class UserSettings(wx.Frame):
             style=wx.CB_DROPDOWN | wx.CB_READONLY,
         )
         self.spin_ctrl_alpha_input = wx.SpinCtrlDouble(
-            self, wx.ID_ANY, "0", min=0, max=1.0, style=wx.SP_ARROW_KEYS
+            self,
+            wx.ID_ANY,
+            "0",
+            min=0,
+            max=1.0,
+            style=wx.SP_ARROW_KEYS,
+            inc=0.1,
         )
+
+        if is_windows():
+            self.checkbox_edge_backend = wx.CheckBox(
+                self, wx.ID_ANY, "Enable Edge WebView Backend"
+            )
+            if not is_edge_backend_available():
+                self.checkbox_edge_backend.Disable()
+
         self.button_restore_defaults = wx.Button(
             self, wx.ID_ANY, "Restore Defaults"
         )
@@ -1020,6 +1039,8 @@ class UserSettings(wx.Frame):
         )
         # self.dvh_bin_width_input.SetMinSize((50, 22))
         # self.dvh_bin_max_dose_units.SetMinSize((50, 22))
+        self.ovh_resolution_input.SetToolTip("Value must be numeric.")
+        self.ovh_resolution_input.SetMinSize((50, 21))
         self.combo_box_colors_category.SetMinSize(
             (250, self.combo_box_colors_category.GetSize()[1])
         )
@@ -1056,6 +1077,17 @@ class UserSettings(wx.Frame):
         )
         self.combo_box_sizes_category.SetValue("Plot Axis Label Font Size")
 
+        if is_windows():
+            self.checkbox_edge_backend.SetValue(
+                self.options.ENABLE_EDGE_BACKEND
+            )
+            self.checkbox_edge_backend.SetToolTip(
+                "Allows for more complete plot interaction. Must restart DVHA for "
+                "change to be applied. If you cannot toggle this checkbox, "
+                "Edge is not availabe. Requires MS Edge Beta to be installed: "
+                "https://www.microsoftedgeinsider.com/en-us/download"
+            )
+
     def __do_layout(self):
         sizer_wrapper = wx.BoxSizer(wx.VERTICAL)
         sizer_ok_cancel = wx.BoxSizer(wx.HORIZONTAL)
@@ -1063,13 +1095,14 @@ class UserSettings(wx.Frame):
             wx.StaticBox(self, wx.ID_ANY, "Plot Options"), wx.VERTICAL
         )
         sizer_dvh_options = wx.StaticBoxSizer(
-            wx.StaticBox(self, wx.ID_ANY, "DVH Options"), wx.VERTICAL
+            wx.StaticBox(self, wx.ID_ANY, "DVH/OVH Options"), wx.VERTICAL
         )
         sizer_dvh_bin_width = wx.BoxSizer(wx.HORIZONTAL)
         sizer_dvh_bin_max = wx.BoxSizer(wx.HORIZONTAL)
         sizer_dvh_small_vol = wx.BoxSizer(wx.HORIZONTAL)
         sizer_dvh_segments_between = wx.BoxSizer(wx.HORIZONTAL)
         sizer_dvh_high_resolution = wx.BoxSizer(wx.HORIZONTAL)
+        sizer_ovh_resolution = wx.BoxSizer(wx.HORIZONTAL)
         sizer_alpha = wx.BoxSizer(wx.VERTICAL)
         sizer_alpha_input = wx.BoxSizer(wx.HORIZONTAL)
         sizer_line_styles = wx.BoxSizer(wx.VERTICAL)
@@ -1182,6 +1215,14 @@ class UserSettings(wx.Frame):
             sizer_dvh_high_resolution, 0, wx.EXPAND | wx.TOP | wx.LEFT, 5
         )
 
+        label_ovh_res = wx.StaticText(self, wx.ID_ANY, "OVH Resolution (mm):")
+        label_ovh_res.SetToolTip("Set to 0 to skip calculations.")
+        sizer_ovh_resolution.Add(
+            label_ovh_res, 1, wx.EXPAND | wx.TOP | wx.LEFT, 5
+        )
+        sizer_ovh_resolution.Add(self.ovh_resolution_input, 0, wx.ALL, 5)
+        sizer_dvh_options.Add(sizer_ovh_resolution, 0, wx.EXPAND | wx.TOP, 5)
+
         sizer_wrapper.Add(sizer_dvh_options, 0, wx.ALL | wx.EXPAND, 10)
 
         label_colors = wx.StaticText(self, wx.ID_ANY, "Colors:")
@@ -1229,6 +1270,10 @@ class UserSettings(wx.Frame):
         sizer_alpha_input.Add(self.spin_ctrl_alpha_input, 0, 0, 0)
         sizer_alpha.Add(sizer_alpha_input, 1, wx.EXPAND, 0)
         sizer_plot_options.Add(sizer_alpha, 1, wx.EXPAND, 0)
+        if is_windows():
+            sizer_plot_options.Add(
+                self.checkbox_edge_backend, 0, wx.EXPAND | wx.TOP, 5
+            )
         sizer_wrapper.Add(
             sizer_plot_options, 1, wx.EXPAND | wx.LEFT | wx.RIGHT | wx.TOP, 10
         )
@@ -1266,6 +1311,11 @@ class UserSettings(wx.Frame):
             self.update_dvh_bin_width_val,
             id=self.dvh_bin_width_input.GetId(),
         )
+        self.Bind(
+            wx.EVT_TEXT,
+            self.update_ovh_resolution_val,
+            id=self.ovh_resolution_input.GetId(),
+        )
         self.Bind(
             wx.EVT_TEXT,
             self.update_dvh_bin_max_dose_val,
@@ -1342,6 +1392,12 @@ class UserSettings(wx.Frame):
             self.update_alpha_val,
             id=self.spin_ctrl_alpha_input.GetId(),
         )
+        if is_windows() and is_edge_backend_available():
+            self.Bind(
+                wx.EVT_CHECKBOX,
+                self.on_enable_edge,
+                id=self.checkbox_edge_backend.GetId(),
+            )
 
         self.Bind(
             wx.EVT_BUTTON,
@@ -1545,7 +1601,7 @@ class UserSettings(wx.Frame):
     def update_dvh_bin_width_val(self, *args):
         new = self.dvh_bin_width_input.GetValue()
         try:
-            val = abs(int(new))
+            val = abs(int(float(new)))
             self.options.set_option("dvh_bin_width", val)
         except ValueError:
             if new != "":
@@ -1553,8 +1609,22 @@ class UserSettings(wx.Frame):
                     str(self.options.dvh_bin_width)
                 )
 
+    def update_ovh_resolution_val(self, *args):
+        new = self.ovh_resolution_input.GetValue()
+        try:
+            val = abs(float(new))
+            self.options.set_option("OVH_RESOLUTION", val)
+        except ValueError:
+            if new != "":
+                self.ovh_resolution_input.SetValue(
+                    str(self.options.OVH_RESOLUTION)
+                )
+
     def update_dvh_bin_width_var(self, *args):
-        self.dvh_bin_width_input.SetValue(str(self.options.dvh_bin_width))
+        self.dvh_bin_width_input.SetValue("%0.1f" % self.options.dvh_bin_width)
+
+    def update_ovh_resolution_var(self, *args):
+        self.ovh_resolution_input.SetValue(str(self.options.OVH_RESOLUTION))
 
     def update_dvh_bin_max_dose_val(self, *args):
         new_val = self.dvh_bin_max_dose.GetValue()
@@ -1615,6 +1685,7 @@ class UserSettings(wx.Frame):
 
     def refresh_options(self):
         self.update_dvh_bin_width_var()
+        self.update_ovh_resolution_var()
         self.update_dvh_bin_max_dose_var()
         self.update_dvh_bin_max_dose_units_var()
         self.update_alpha_var()
@@ -1642,6 +1713,11 @@ class UserSettings(wx.Frame):
             "USE_DICOM_DVH", self.checkbox_dicom_dvh.GetValue()
         )
 
+    def on_enable_edge(self, *evt):
+        self.options.set_option(
+            "ENABLE_EDGE_BACKEND", self.checkbox_edge_backend.GetValue()
+        )
+
     def on_apply(self, *evt):
         self.apply_and_redraw_plots()
         self.is_edited = True  # Used to track edits since last options save
