@@ -292,13 +292,16 @@ class DefaultOptions:
             "interpolation_segments_between_planes": 0,
             "memmap_rtdose": False,
         }
-        self.DVH_SMALL_VOLUME_THRESHOLD = (
-            10  # compute high resolution DVH if volume less than this (cc)
-        )
-        self.DVH_HIGH_RESOLUTION_FACTOR = 8  # Must be a factor of 2
+        # compute high resolution DVH if volume less than this (cc)
+        self.DVH_SMALL_VOLUME_THRESHOLD = 3
+        self.DVH_HIGH_RESOLUTION_FACTOR = 4  # Must be a factor of 2
         self.DVH_HIGH_RESOLUTION_FACTOR_OPTIONS = ["2", "4", "8", "16", "32"]
         self.DVH_HIGH_RESOLUTION_SEGMENTS_BETWEEN = 3  # Must be int
 
+        self.ENABLE_EDGE_BACKEND = False
+
+        self.OVH_RESOLUTION = 3  # mm
+
 
 class Options(DefaultOptions):
     def __init__(self):
